@@ -6,7 +6,7 @@ use 5.014;
 use FASTX::Reader;
 use Getopt::Long;
 use File::Basename;
-
+use Pod::Usage;
 my $PROGRAM = 'fqlen';
 my $VERSION = '0.1';
 my $DESCR   = 'Select sequences by size';
@@ -19,15 +19,16 @@ my %schemes = (
 	'num' => 'Numbered sequence (see also -p)',
 	'file'=> 'Use file basename as prefix',
 );
+my $opt_minlen = 1;
+my $opt_maxlen = 0;
 my (
-  $opt_minlen,
-  $opt_maxlen,
   $opt_fasta_format,
   $opt_fasta_width,
   $opt_verbose,
   $opt_prefix,
   $opt_strip_comment,
   $opt_addlength,
+  $opt_help,
 );
 my  $opt_name = 'raw';
 my  $opt_separator = '.';
@@ -42,8 +43,9 @@ my $_opt = GetOptions(
  'l|len'             => \$opt_addlength,
  's|separator=s'     => \$opt_separator,
  'p|prefix=s'        => \$opt_prefix,
+ 'h|help'            => \$opt_help,
 );
-
+pod2usage({-exitval => 0, -verbose => 2}) if $opt_help;
 usage() unless defined $ARGV[0];
 
 # Check schemes
@@ -56,26 +58,30 @@ if (not defined $schemes{$opt_name}) {
 my $sep = '';
 $sep = $opt_separator if ($opt_prefix);
 
-my $global_counter++;
-
+my $global_counter = 0;
+my $global_printed = 0;
 my %check_reads;
 foreach my $input_file (@ARGV) {
 	if (! -e "$input_file") {
 		verbose(qq(Skipping "$input_file": file not found));
 		next;
-	}
+	} elsif (-d "$input_file") {
+		verbose(qq(Skipping "$input_file": is a directory));
+		next;
+	} 
 	my $reader = FASTX::Reader->new({ filename => "$input_file" });
 	my $local_counter = 0;
+	my $local_printed = 0;
 	while (my $s = $reader->getRead() ) {
 	
 		my $len = length($s->{seq});
-		
+		$global_counter++;
+		$local_counter++;			
 		# Length Check
 		next if ($len < $opt_minlen);
-		next if ($len > $opt_maxlen);
+		next if ($opt_maxlen > 0 and $len > $opt_maxlen);
+		
 
-		$global_counter++;
-		$local_counter++;	
 		# Read name
 		my $name;
 		if ($opt_name eq 'raw') {
@@ -95,13 +101,14 @@ foreach my $input_file (@ARGV) {
 		my $quality  = $s->{qual};
 
 		if ($check_reads{$name}) {
-			die "Duplicate read name <$name> using scheme $opt_name.\nReading <$input_file>, sequence number $local_counter (total sequences $global_counter)\n";
+			die "FATAL ERROR: Duplicate read name <$name> using scheme $opt_name.\nReading <$input_file>, sequence number $local_counter (total sequences $global_counter)\n";
 		}
 
 		$check_reads{$name}++;
-
+		$global_printed++;
+		$local_printed++;
 		# Print
-		if ($opt_fasta_format or not defined $s->{quality}) {
+		if ($opt_fasta_format or not defined $quality) {
 			# In fasta format
 			print '>', $name, "\n", format_dna($sequence, $opt_fasta_width);
 		} else {
@@ -109,9 +116,15 @@ foreach my $input_file (@ARGV) {
 			print '@', $name, "\n", $sequence, "\n+\n", $quality, "\n";
 		}
 	}
+	if ($opt_verbose and $global_counter > 0) {
+	say STDERR " [$input_file]. ", sprintf("%.2f", 100*$global_printed/$global_counter), "% sequences selected.";
+	}
 
 }
 
+if ($opt_verbose and $global_counter > 0) {
+	say STDERR " [ALL_DONE]. ", sprintf("%.2f", 100*$global_printed/$global_counter), "% sequences selected.";
+}
 sub format_dna {
 	my ($sequence, $width) = @_;
 	if (not defined $width) {
@@ -140,8 +153,8 @@ sub usage {
   Synopsis:
     fqlen [options] FILE1 FILE2 ... FILEn
 
-  -m, --min INT                   Minimum length to print a sequence
-  -x, --max INT                   Maximum length to print a sequence
+  -m, --min INT                   Minimum length to print a sequence [default: 1]
+  -x, --max INT                   Maximum length to print a sequence [default: 0 for unlimited]
   -l, --len                       Add read length as comment
   -f, --fasta                     Force FASTA output (default: as INPUT)
   -w, --fasta-width INT           Paginate FASTA sequences (default: no)
@@ -177,7 +190,65 @@ fqlen.pl - A demo implementation to filter fastx files by length
 
 =head1 VERSION
 
-version 1.5.0
+version 1.5.1
+
+=head1 SYNOPSIS
+
+  fqc [options] [FILE1 FILE2 FILE3...]
+
+=head1 DESCRIPTION
+
+A program to filter sequences by minimum/maximum lengths.
+Can process multiple files and rename the produced sequences.
+
+=head1 PARAMETERS
+
+=head2 FILE NAME
+
+=over 4
+
+=item I<-a, --abspath>
+
+Print the absolute path of the filename (the absolute path is always the table key,
+but if relative paths are supplied, they will be printed).
+
+=item I<-m, --min INT>
+
+Minimum length to print a sequence
+
+=item I<-x, --max INT>
+
+Maximum length to print a sequence
+
+=item I<-l, --len>
+
+Add read length as comment
+
+=item I<-f, --fasta>
+
+Force FASTA output (default: as INPUT)
+
+=item I<-w, --fasta-width INT>
+
+Paginate FASTA sequences (default: no)
+
+=item I<-n, --namescheme>
+
+Sequence name scheme:
+
+=item I<-p, --prefix STR>
+
+Use as sequence name prefix this string
+
+=item I<-c, --strip-comment>
+
+Remove sequence comment (default: no)
+
+=item I<--verbose>
+
+Add verbose feedback on % of printed reads
+
+=back
 
 =head1 AUTHOR
 
